import { Route, Switch } from "wouter";
import inDebug from "../utils/inDebug";
import { RoutingTree } from "../types/routesTypes";
import { SwitchRouteGeneratorProps } from "../types/switchRouteGeneratorTypes";

const routesCrawler = (
	routesTree: RoutingTree,
	parentPath?: string,
): JSX.Element[] => {
	return routesTree.map((route): JSX.Element => {
		// -----
		if (route.path) {
			const _path = (
				parentPath && parentPath !== "/" ? parentPath + route.path : route.path
			).replace("//", "/");
			// Debug log shows generated routes
			inDebug(() => console.log("routesCrawler_routes", route.name, _path));
			// -----
			if (route.nest) {
				return (
					<Route key={_path} path={_path}>
						<Switch key={`${route.name}_switch_route`}>
							{routesCrawler(route.nest, _path)}
						</Switch>
					</Route>
				);
			} else return <Route key={_path} path={_path} component={route.component} />;
		} else return <Route key={route.name} component={route.component} />;
	});
};

/**
 * This component is used to generate Switch with Routes for given routes object
 */
const SwitchRouteGenerator = ({ routesTree }: SwitchRouteGeneratorProps) => {
	return <Switch key={"main_switch_route"}>{routesCrawler(routesTree)}</Switch>;
};
export default SwitchRouteGenerator;
